'use strict';

var _expect = require('expect.js');

var _expect2 = _interopRequireDefault(_expect);

var _jss = require('jss');

var _jss2 = _interopRequireDefault(_jss);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactDom = require('react-dom');

var _ = require('./');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var node = document.createElement('div');

describe('react-jss', function () {
  describe('.create()', function () {
    var localInjectSheet = void 0;
    var localJss = void 0;

    beforeEach(function () {
      localJss = (0, _jss.create)();
      localInjectSheet = (0, _.create)(localJss);
    });

    afterEach(function () {
      (0, _reactDom.unmountComponentAtNode)(node);
    });

    it('should return a function', function () {
      (0, _expect2['default'])(_2['default']).to.be.a(Function);
    });

    it('should use passed jss', function () {
      var passedJss = void 0;
      var Component = function Component(_ref) {
        var sheet = _ref.sheet;

        passedJss = sheet.options.jss;
        return null;
      };
      var WrappedComponent = localInjectSheet()(Component);
      (0, _reactDom.render)(_react2['default'].createElement(WrappedComponent, null), node);
      (0, _expect2['default'])(_2['default']);
      (0, _expect2['default'])(passedJss).to.be(localJss);
    });
  });

  describe('global jss instance', function () {
    it('should return a function', function () {
      (0, _expect2['default'])(_2['default']).to.be.a(Function);
    });

    it('should be available', function () {
      (0, _expect2['default'])(_.jss).to.be.an(_jss2['default'].constructor);
    });
  });

  describe('.injectSheet()', function () {
    var WrappedComponent = void 0;

    beforeEach(function () {
      var Component = function Component() {
        return null;
      };
      WrappedComponent = (0, _2['default'])({
        button: { color: 'red' }
      })(Component);
    });

    it('should attach and detach a sheet', function () {
      (0, _reactDom.render)(_react2['default'].createElement(WrappedComponent, null), node);
      (0, _expect2['default'])(document.querySelectorAll('style').length).to.be(1);
      (0, _reactDom.unmountComponentAtNode)(node);
      (0, _expect2['default'])(document.querySelectorAll('style').length).to.be(0);
    });

    it('should reuse one sheet for 2 elements and detach sheet', function () {
      (0, _reactDom.render)(_react2['default'].createElement(WrappedComponent, null), node);
      (0, _reactDom.render)(_react2['default'].createElement(WrappedComponent, null), node);
      (0, _expect2['default'])(document.querySelectorAll('style').length).to.be(1);
      (0, _reactDom.unmountComponentAtNode)(node);
      (0, _expect2['default'])(document.querySelectorAll('style').length).to.be(0);
    });
  });

  describe('.injectSheet() without a component for global styles', function () {
    var Container = void 0;

    beforeEach(function () {
      Container = (0, _2['default'])({
        button: { color: 'red' }
      })();
    });

    it('should attach and detach a sheet', function () {
      (0, _reactDom.render)(_react2['default'].createElement(Container, null), node);
      (0, _expect2['default'])(document.querySelectorAll('style').length).to.be(1);
      (0, _reactDom.unmountComponentAtNode)(node);
      (0, _expect2['default'])(document.querySelectorAll('style').length).to.be(0);
    });

    it('should render children', function () {
      var isRendered = true;
      var Component = function Component() {
        isRendered = true;
        return null;
      };
      (0, _reactDom.render)(_react2['default'].createElement(
        Container,
        null,
        _react2['default'].createElement(Component, null)
      ), node);
      (0, _reactDom.unmountComponentAtNode)(node);
      (0, _expect2['default'])(isRendered).to.be(true);
    });
  });
});